﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.Controls;
using CMS.GlobalHelper;
using System.Collections;
using System.Data;

public partial class CMSGlobalFiles_MenuFilter : CMSAbstractMenuFilterControl
{
    #region "Methods"

    /// <summary>
    /// Setup the inner child controls
    /// </summary>
    private void SetupControl()
    {
        // Hide the filter if StopProcessing is enabled
        if (this.StopProcessing)
        {
            this.Visible = false;
        }

        // Initialize only if the current request is NOT a postback
        if (!RequestHelper.IsPostBack())
        {
            // Initialize child controls
            InitializeChildControls();
        }
    }


    private void InitializeChildControls()
    {
        if (ValidationHelper.GetBoolean(CookieHelper.GetValue("ApplyMenuDesign"), false) == true)
        {
            chckApplyMenuDesign.Checked = true;
        }
        else
        {
            chckApplyMenuDesign.Checked = false;
        }

        this.ApplyMenuDesign = chckApplyMenuDesign.Checked;

        if (ValidationHelper.GetBoolean(CookieHelper.GetValue("DocumentMenuRedirectUrl"), false) == true)
        {
            chckMenuReditectURL.Checked = true;
        }
        else
        {
            chckMenuReditectURL.Checked = false;
        }

    }


    /// <summary>
    /// Sets filter conditions
    /// </summary>
    private void SetFilter()
    {
        string where = null;

        if (chckMenuReditectURL.Checked)
        {
            where = "DocumentMenuRedirectUrl != ''";
            CookieHelper.SetValue("DocumentMenuRedirectUrl", "true", DateTime.Now.AddDays(5));
        }
        else
        {
            CookieHelper.SetValue("DocumentMenuRedirectUrl", "false", DateTime.Now.AddDays(5));
        }
        
        if (!string.IsNullOrEmpty(where))
        {
            this.WhereCondition = where;
        }
        
        this.ApplyMenuDesign = chckApplyMenuDesign.Checked;

        if (this.ApplyMenuDesign)
        {
            CookieHelper.SetValue("ApplyMenuDesign", "true", DateTime.Now.AddDays(5));
        }
        else
        {
            CookieHelper.SetValue("ApplyMenuDesign", "false", DateTime.Now.AddDays(5));
        }

        // Raise the filter changed event
        this.RaiseOnFilterChanged();
    }


    /// <summary>
    /// Init event handler
    /// </summary>
    protected override void OnInit(EventArgs e)
    {
        // Create child controls
        SetupControl();
        base.OnInit(e);
    }


    /// <summary>
    /// PreRender event handler
    /// </summary>
    protected override void OnPreRender(EventArgs e)
    {
        // Apply the filter to the displayed data
        SetFilter();

        base.OnPreRender(e);
    }

    #endregion
}