﻿using System;
using System.Collections.Generic;
using System.Collections;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.Caching;

using CMS.Controls;
using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.SettingsProvider;

public partial class CMSGlobalFiles_UsersFilter : CMSAbstractBaseFilterControl
{
    #region "Methods"

    /// <summary>
    /// Setup the inner child controls
    /// </summary>
    private void SetupControl()
    {
        // Hide the filter if StopProcessing is enabled
        if (this.StopProcessing)
        {
            this.Visible = false;
        }
    }


    /// <summary>
    /// Generates a WHERE condition and ORDER BY clause based on the current filtering selection
    /// </summary>
    private void SetFilter()
    {
        string where = null;

        if (!string.IsNullOrEmpty(txtSearch.Text.Trim()))
        {
            where = "(FirstName LIKE '%" + txtSearch.Text.Trim().Replace("'", "''") + "%')";
        }

        if (where != null)
        {
                // Set where condition
                this.WhereCondition += where;
        }

        #region "Custom CacheItemName"

        foreach (DictionaryEntry item in CMSControlsHelper.CurrentFilters)
        {
            CMSBaseDataSource source = null;
            try
            {
                source = CMSControlsHelper.CurrentFilters[item.Key] as CMSBaseDataSource;

                if (source.SourceFilterName.ToLower().Equals(this.FilterName.ToLower()))
                {

                    source.CacheItemName += "|" + this.WhereCondition;
                }
            }
            catch { }
        }

        #endregion
    }


    /// <summary>
    /// Init event handler
    /// </summary>
    protected override void OnInit(EventArgs e)
    {
        // Create child controls
        SetupControl();
        base.OnInit(e);
    }
    

    /// <summary>
    /// Onload event handler
    /// </summary>
    protected override void OnLoad(EventArgs e)
    {
        if (!string.IsNullOrEmpty(SourceFilterName))
        {
            CMSAbstractBaseFilterControl sourcefilter = CMSControlsHelper.CurrentFilters[SourceFilterName] as CMSAbstractBaseFilterControl;
            if (sourcefilter != null)
            {
                sourcefilter.OnFilterChanged += new ActionEventHandler(source_OnFilterChanged);
            }
        }
        base.OnLoad(e);
    }


    void source_OnFilterChanged()
    {
        SetFilter();
        this.FilterChanged = true;
    }


    /// <summary>
    /// PreRender event handler
    /// </summary>
    protected override void OnPreRender(EventArgs e)
    {
        // Check if the current request is a postback
        if (RequestHelper.IsPostBack() && (this.SourceFilterControl == null || this.SourceFilterControl.FilterChanged != true))
        {
            // Apply the filter to the displayed data
            SetFilter();
            // Raise the filter changed event
            this.RaiseOnFilterChanged();
        }
        base.OnPreRender(e);
    }

    #endregion
}