﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.PortalControls;
using CMS.GlobalHelper;

public partial class CMSWebParts_DataSources_ExcelDataSource : CMSAbstractWebPart
{

    #region "Public Properties"

    /// <summary>
    /// Gets or sets WHERE condition.
    /// </summary>
    public string WhereCondition
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("WhereCondition"), "");
        }
        set
        {
            this.SetValue("WhereCondition", value);
            srcExcel.WhereCondition = value;
        }
    }


    /// <summary>
    /// Gets or sets ORDER BY condition.
    /// </summary>
    public string OrderBy
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("OrderBy"), "");
        }
        set
        {
            this.SetValue("OrderBy", value);
            srcExcel.OrderBy = value;
        }
    }


    /// <summary>
    /// Gets or sets the source filter name
    /// </summary>
    public string FilterName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("FilterName"), "");
        }
        set
        {
            this.SetValue("FilterName", value);
            srcExcel.SourceFilterName = value;
        }
    }


    /// <summary>
    /// Gets or sets excel file URL.
    /// </summary>
    public string FilePath
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("FilePath"), "");
        }
        set
        {
            this.SetValue("FilePath", value);
            srcExcel.FilePath = value;
        }
    }


    /// <summary>
    /// Gets or sets excel provider.
    /// </summary>
    public string ExcelProvider
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ExcelProvider"), "");
        }
        set
        {
            this.SetValue("ExcelProvider", value);
            srcExcel.ExcelProvider = value;
        }
    }


    /// <summary>
    /// Gets or sets excel provider.
    /// </summary>
    public string ExcelExtendedProperties
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ExcelExtendedProperties"), "");
        }
        set
        {
            this.SetValue("ExcelExtendedProperties", value);
            srcExcel.ExcelExtendedProperties = value;
        }
    }


    /// <summary>
    /// Gets or sets excel provider.
    /// </summary>
    public string TableName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("TableName"), "");
        }
        set
        {
            this.SetValue("TableName", value);
            srcExcel.TableName = value;
        }
    }


    /// <summary>
    /// Gets or sets columns to be selected.
    /// </summary>
    public string Columns
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("Columns"), "");
        }
        set
        {
            this.SetValue("Columns", value);
            srcExcel.SelectedColumns = value;
        }
    }
    

    /// <summary>
    /// Gets or sets the cache item name
    /// </summary>
    public override string CacheItemName
    {
        get
        {
            return base.CacheItemName;
        }
        set
        {
            base.CacheItemName = value;
            this.srcExcel.CacheItemName = value;
        }
    }


    /// <summary>
    /// Cache dependencies, each cache dependency on a new line
    /// </summary>
    public override string CacheDependencies
    {
        get
        {
            return ValidationHelper.GetString(base.CacheDependencies, this.srcExcel.CacheDependencies);
        }
        set
        {
            base.CacheDependencies = value;
            this.srcExcel.CacheDependencies = value;
        }
    }


    /// <summary>
    /// Gets or sets the cache minutes
    /// </summary>
    public override int CacheMinutes
    {
        get
        {
            return base.CacheMinutes;
        }
        set
        {
            base.CacheMinutes = value;
            this.srcExcel.CacheMinutes = value;
        }
    }

    #endregion


    #region "Methods"

    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if (this.StopProcessing)
        {
            // Do nothing
        }
        else
        {
            this.srcExcel.WhereCondition = this.WhereCondition;
            this.srcExcel.OrderBy = this.OrderBy;
            this.srcExcel.FilePath = UrlHelper.ResolveUrl(this.FilePath);
            this.srcExcel.ExcelProvider = this.ExcelProvider;
            this.srcExcel.ExcelExtendedProperties = this.ExcelExtendedProperties;
            this.srcExcel.TableName = this.TableName;
            this.srcExcel.SelectedColumns = this.Columns;
            this.srcExcel.CacheItemName = this.CacheItemName;
            this.srcExcel.CacheMinutes = this.CacheMinutes;
            this.srcExcel.CacheDependencies = this.CacheDependencies;
            
            // Sets the current web part name as datasource name
            this.srcExcel.FilterName = ValidationHelper.GetString(this.GetValue("WebPartControlID"), this.ClientID);

            // Sets the name of the extending filter
            this.srcExcel.SourceFilterName = this.FilterName;
        }
    }


    /// <summary>
    /// Clears cache.
    /// </summary>
    public override void ClearCache()
    {
        srcExcel.ClearCache();
    }

    #endregion
}