﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data.OleDb;
using System.Data;

using CMS.Controls;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSWebParts_DataSources_ExcelDataSource_files_ExcelDataSourceControl : CMSBaseDataSource
{
    #region "Private variables"

    private string mWhereCondition = String.Empty;
    private string mOrderBy = String.Empty;
    private string mFilePath = String.Empty;
    private string mExcelProvider = String.Empty;
    private string mExcelExtendedProperties = String.Empty;
    private string mTableName = String.Empty;
    private string mColumns = String.Empty;
    private bool filtered = false;

    #endregion


    #region "Public properties"

    /// <summary>
    /// Gets or sets the where condition
    /// </summary>
    public override string WhereCondition
    {
        get
        {
            return mWhereCondition;
        }
        set
        {
            mWhereCondition = value;
        }
    }


    /// <summary>
    /// Gets or sets the file URL
    /// </summary>
    public string FilePath
    {
        get
        {
            return mFilePath;
        }
        set
        {
            mFilePath = value;
        }
    }


    /// <summary>
    /// Gets the data source
    /// </summary>
    public override object DataSource
    {
        get
        {
            if (!DataHelper.DataSourceIsEmpty(base.DataSource))
            {
                return base.DataSource;
            }
            else
            {
                return base.GetDataSource();
            }
        }
    }


    /// <summary>
    /// Gets or sets the order by clause
    /// </summary>
    public string OrderBy
    {
        get
        {
            return mOrderBy;
        }
        set
        {
            mOrderBy = value;
        }
    }


    /// <summary>
    /// Gets or sets excel provider
    /// </summary>
    public string ExcelProvider
    {
        get
        {
            return mExcelProvider;
        }
        set
        {
            mExcelProvider = value;
        }
    }


    /// <summary>
    /// Gets or sets excel extented properties
    /// </summary>
    public string ExcelExtendedProperties
    {
        get
        {
            return mExcelExtendedProperties;
        }
        set
        {
            mExcelExtendedProperties = value;
        }
    }


    /// <summary>
    /// Gets or sets table name
    /// </summary>
    public string TableName
    {
        get
        {
            return mTableName;
        }
        set
        {
            mTableName = value;
        }
    }

    #endregion


    #region "Methods"

    /// <summary>
    /// Handle filter change event
    /// </summary>
    protected override void OnInit(EventArgs e)
    {
        if (SourceFilterControl != null)
        {
            SourceFilterControl.OnFilterChanged += new ActionEventHandler(DataFilter_OnFilterChanged);
        }

        base.OnInit(e);
    }


    /// <summary>
    /// OnFilterChange handler
    /// </summary>
    void DataFilter_OnFilterChanged()
    {
        // Clear old data
        InvalidateLoadedData();
        // Raise change event
        this.RaiseOnFilterChanged();
    }


    /// <summary>
    /// Gets the datasource data
    /// </summary>
    public override object GetDataSourceFromDB()
    {
        // Check whether datasource contains data
        if (base.DataSource != null)
        {
            return base.DataSource;
        }

        // Initialize data and return datasource
        else
        {
            // Initialize properties with dependence on filter settings
            if (SourceFilterControl != null && !filtered)
            {
                SourceFilterControl.InitDataProperties(this);
            }

            base.DataSource = FilterDS(GetDataSourceFromExcel(this.FilePath));
            return base.DataSource;
        }
    }


    /// <summary>
    /// Gets the datasource data from excel
    /// </summary>
    public object GetDataSourceFromExcel(string filePath)
    {
        // Create new DataSet to hold information from the worksheet.
        DataSet objDataset = new DataSet();

        try
        {
            // Create connection string variable.
            String sConnectionString = "Provider=" + this.ExcelProvider + ";" +
                "Data Source=" + Server.MapPath(filePath) + ";" +
                "Extended Properties=\"" + this.ExcelExtendedProperties + "\"";

            OleDbConnection objConn = new OleDbConnection(sConnectionString);
            objConn.Open();

            if (string.IsNullOrEmpty(SelectedColumns))
            {
                this.SelectedColumns = "*";
            }

            OleDbCommand objCmdSelect = new OleDbCommand("SELECT " + this.SelectedColumns + " FROM " + this.TableName, objConn);
            OleDbDataAdapter objAdapter = new OleDbDataAdapter();
            objAdapter.SelectCommand = objCmdSelect;
            objAdapter.Fill(objDataset, "XLSData");
            
            objConn.Close();
        }
        catch
        {
        }
 
        return objDataset;
    }


    /// <summary>
    /// Filter the data source
    /// </summary>
    public object FilterDS(object objDataset)
    {
        try
        {
            if (!DataHelper.DataSourceIsEmpty(objDataset))
            {
                if (objDataset.GetType() == typeof(DataView))
                {
                    DataView dw = objDataset as DataView;
                    if (!string.IsNullOrEmpty(this.WhereCondition))
                    {
                        dw.RowFilter = this.WhereCondition;
                        filtered = true;
                    }
                    if (!string.IsNullOrEmpty(this.OrderBy))
                    {
                        dw.Sort = this.OrderBy;
                        filtered = true;
                    }
                    return dw;
                }
                else if (objDataset.GetType() == typeof(DataSet))
                {
                    DataSet ds = objDataset as DataSet;
                    if (!string.IsNullOrEmpty(this.WhereCondition))
                    {
                        ds.Tables[0].DefaultView.RowFilter = this.WhereCondition;
                        filtered = true;
                    }
                    if (!string.IsNullOrEmpty(this.OrderBy))
                    {
                        ds.Tables[0].DefaultView.Sort = this.OrderBy;
                        filtered = true;
                    }
                    return ds.Tables[0].DefaultView;
                }
            }
        }
        catch { }

        return objDataset;
    }


    /// <summary>
    /// Clears the cached items
    /// </summary>
    public void ClearCache()
    {
        // Prepare the cache item name
        string useCacheItemName = CacheHelper.GetCacheItemName(this.CacheItemName, "basedatasource", CMSContext.BaseCacheKey, this.ClientID, this.WhereCondition, this.OrderBy);

        CacheHelper.ClearCache(useCacheItemName);
    }

    #endregion
}