﻿using System;
using System.Collections.Generic;
using System.Collections;
using System.Linq;
using System.Data;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.Controls;
using CMS.PortalControls;
using CMS.GlobalHelper;

public partial class CMSWebParts_DataSources_ExcelDataSource_files_ExcelFilter : CMSAbstractBaseFilterControl
{
    #region "Constants"

    public const string ALL = "##ALL##";

    #endregion

    #region "Private variables"

    private object mDataSource = null;

    #endregion

    #region "Properties"

    /// <summary>
    /// Gets the data source
    /// </summary>
    public object DataSource
    {
        get
        {
            return mDataSource;
        }
        set
        {
            mDataSource = value;
        }
    }

    #endregion

    #region "Methods"

    /// <summary>
    /// Setup the inner child controls
    /// </summary>
    private void SetupControl()
    {
        // Hide the filter if StopProcessing is enabled
        if (this.StopProcessing)
        {
            this.Visible = false;
        }

        // Get data source from connected/related data source control
        GetDataSource();
        
        // Initialize only if the current request is NOT a postback
        if (!RequestHelper.IsPostBack())
        {
            // Loads list of all available columns from excel data source
            InitializeColumns();
        }
    }


    public void GetDataSource()
    {
        foreach (DictionaryEntry item in CMSControlsHelper.CurrentFilters)
        {
            CMSBaseDataSource source = null;
            try
            {
                source = CMSControlsHelper.CurrentFilters[item.Key] as CMSBaseDataSource;

                if (source != null && !DataHelper.DataSourceIsEmpty(source.DataSource) && source.SourceFilterName.ToLower().Equals(this.FilterName.ToLower()))
                {
                    this.DataSource = source.DataSource;
                    return;
                }
            }
            catch { }
        }
    }


    /// <summary>
    /// Loads all available columns from excel data source into the columns drop-down list
    /// </summary>
    private void InitializeColumns()
    {
        DataTable dt = DataHelper.GetDataTable(this.DataSource);

        if (!DataHelper.DataSourceIsEmpty(dt))
        {
            if (drpColumns.Items.Count == 0)
            {
                this.drpColumns.Items.Add(new ListItem("All", ALL));

                foreach (DataColumn dc in dt.Columns)
                {
                    this.drpColumns.Items.Add(new ListItem(dc.ColumnName, dc.ColumnName));
                }
            }
        }
    }


    /// <summary>
    /// Generates a WHERE condition and ORDER BY clause based on the current filtering selection
    /// </summary>
    private void SetFilter()
    {
        string where = null;
        string order = null;

        if (drpColumns.Items.Count > 0)
        {
            if (!drpColumns.SelectedValue.Equals(ALL))
            {
                where = GetCondition(txtSearch.Text.Trim(), drpColumns.SelectedValue); 
            }
            else
            {
                foreach (ListItem item in drpColumns.Items)
                {
                    if (!item.Value.Equals(ALL))
                    {
                        string tempWhere = GetCondition(txtSearch.Text.Trim(), item.Value);

                        if (!string.IsNullOrEmpty(where) && !string.IsNullOrEmpty(tempWhere))
                        {
                            where += " OR " + tempWhere;
                        }
                        else
                        {
                            where += tempWhere;
                        }
                    }
                }
            }    
        }
        
        if (where != null)
        {
            // Set where condition
            this.WhereCondition = where;
        }

        if (order != null)
        {
            // Set orderBy clause
            this.OrderBy = order;
        }

        // Raise the filter changed event
        this.RaiseOnFilterChanged();
    }


    /// <summary>
    /// Returns correct where condition
    /// </summary>
    public string GetCondition(string value, string columnName)
    {
        bool isNumberColumn = false;
        DataTable dt = DataHelper.GetDataTable(this.DataSource);
        if (!DataHelper.DataSourceIsEmpty(dt))
        {
            isNumberColumn = dt.Columns[columnName].DataType.FullName.Equals("System.Double");
        }

        if (!isNumberColumn)
        {
            return "(" + columnName + " LIKE '%" + txtSearch.Text.Trim() + "%')";
        }
        else if (ValidationHelper.GetDouble(value, 0) > 0)
        {
            return "(" + columnName + " = '" + txtSearch.Text.Trim() + "')";
        }
        return "";
    }


    /// <summary>
    /// Init event handler
    /// </summary>
    protected override void OnInit(EventArgs e)
    {
        // Create child controls
        SetupControl();
        base.OnInit(e);
    }


    /// <summary>
    /// PreRender event handler
    /// </summary>
    protected override void OnPreRender(EventArgs e)
    {
        // Check if the current request is a postback
        if (RequestHelper.IsPostBack())
        {
            // Apply the filter to the displayed data
            SetFilter();
        }
        base.OnPreRender(e);
    }


    #endregion
}